@@ -4,12 +4,12 @@
  * Copyright 2011 Red Hat, Inc.
  */
 
-#ifndef SOUP_URI_PRIVATE_H
-#define SOUP_URI_PRIVATE_H 1
+#ifndef SOUP_MISC_PRIVATE_H
+#define SOUP_MISC_PRIVATE_H 1
 
 #include "soup-socket.h"
 
-char *uri_decoded_copy (const char *str, int length);
+char *uri_decoded_copy (const char *str, int length, int *decoded_length);
 
 guint soup_socket_handshake_sync  (SoupSocket         *sock,
 				   GCancellable       *cancellable);
@@ -23,7 +23,7 @@ GIOStream *soup_socket_get_connection (SoupSocket *sock);
 GIOStream *soup_socket_get_iostream   (SoupSocket *sock);
 
 #define SOUP_SOCKET_CLEAN_DISPOSE "clean-dispose"
-#define SOUP_SOCKET_USE_PROXY     "use-proxy"
+#define SOUP_SOCKET_PROXY_RESOLVER "proxy-resolver"
 SoupURI *soup_socket_get_http_proxy_uri (SoupSocket *sock);
 
 /* At some point it might be possible to mark additional methods
@@ -41,4 +41,8 @@ SoupURI *soup_socket_get_http_proxy_uri (SoupSocket *sock);
 					   method == SOUP_METHOD_PUT || \
 					   method == SOUP_METHOD_DELETE)
 
-#endif /* SOUP_URI_PRIVATE_H */
+GSource *soup_add_completion_reffed (GMainContext *async_context,
+				     GSourceFunc   function,
+				     gpointer      data);
+
+#endif /* SOUP_MISC_PRIVATE_H */
